class UsersController < ApplicationController
  def self.set_target_before
    super + [:set_password, :send_password_email, :get_password_link]
  end

  model_data_store(User)
  protect_with(nil, nil, [RxModule::Authorization.verb("get_password_link", "Copy Password Link", :get_password_link)])

  # POST /users
  # POST /users.json
  def create
    @model = User.new(model_params)
    @model.password = rand.to_s
    @model.password_confirmation = @model.password

    if @model.save
      render json: @model, status: :created
    else
      render json: @model.errors, status: :unprocessable_entity
    end
  end

  # POST /users/login
  def login
    params.permit(:user_identifier, :password)
    username = params[:user_identifier]
    @model = User.get_by_login_id(username)
    if @model
      if @model.authenticate(params[:password])
        render json: {token: @model.generate_token}, status: :ok
      else
        head :unauthorized
      end
    else
      head :unauthorized
    end
  end

  # POST /users/routine_token
  def routine_token
    raise "Unauthorized" unless RxModule::Authorization.current_user
    routine = params.require(:routine_id)
    user_id = params.permit(:proxy)[:proxy] || RxModule::Authorization.current_user[:id]
    @model = User.find_by(id: user_id)
    render json: {token: @model.generate_token(routine)}
  end

  def set_password
    if @model.consume_recovery_token(params[:token])
      @model.password = params[:password]
      @model.password_confirmation = params[:password_confirmation]
      if @model.save
        render json: @model
      else
        render json: @model.errors, status: :unprocessable_entity
      end
    else
      head :unauthorized
    end
  end

  def send_password_email
    @model.send_password_reset_email
    render json: @model
  end

  def get_password_link
    render json: {link: @model.token_link!}
  end

  def user_pick
    render json: User.for_email_picker
  end

  # POST /users/logout
  def logout
    if logout_params[:hard] && RxModule::Authorization.current_user&.[](:id)
      LoginToken.where(user_id: RxModule::Authorization.current_user[:id], routine: nil).destroy_all
    end
    LoginToken.find_by(value: RxModule::Authorization.current_user_token)&.destroy
  end

  private

  # Never trust parameters from the scary internet, only allow the white list through.
  def model_params
    params.fetch(:user).permit(:email, :name, :table_size, :role_id)
  end

  def logout_params
    params.permit(:hard)
  end
end
