import * as React from "react";
import {Tab, Tabs} from "@material-ui/core";
import {observer} from "mobx-react-lite";
import {ComponentPermissionTab} from "./ComponentPermissionTab";
import {AppsPermissionGroup} from "../../stores/RoleStore";
import {useModelContext} from "@rx-suite/ui";

export const ComponentPermissionForm: React.FunctionComponent = observer(() => {
    const [value, setValue] = React.useState(0);
    const handleChange = (event: any, newValue: React.SetStateAction<number>) => {
        setValue(newValue);
    };

    const model = useModelContext();

    const appsData = model.permissionsByApp as Array<AppsPermissionGroup>;

    return (
        <div>
            <Tabs
                value={value}
                onChange={handleChange}
                indicatorColor="primary"
                textColor="primary"
                variant="scrollable"
            >
                {appsData.sort((a, b) => {
                    const aKey = a?.id || '';
                    const bKey = b?.id || '';
                    return aKey.localeCompare(bKey)
                }).map(app => {
                    return <Tab label={app.module_name} key={app.id as string}/>
                })}
            </Tabs>

            {appsData.map((app, i) => {
                return <ComponentPermissionTab
                    key={app.id}
                    components={app.components}
                    value={value}
                    index={i}
                />
            })}
        </div>
    );
});