import * as React from 'react';
import {observer} from "mobx-react-lite";
import {Dialog, DialogContent, DialogTitle, IconButton} from "@material-ui/core";
import {Settings} from "@material-ui/icons";
import {ModelCheckbox, ModelForm, ModelSelect, useFlag} from "@rx-suite/ui";
import {t, Trans} from "@lingui/macro";
import {CalendarConfigStore} from "../../stores/CalendarConfigStore";

const timeOptions = [
    {label: t`12 am (Day Start)`, value: 0},
    {label: t`1 am`, value: 1},
    {label: t`2 am`, value: 2},
    {label: t`3 am`, value: 3},
    {label: t`4 am`, value: 4},
    {label: t`5 am`, value: 5},
    {label: t`6 am`, value: 6},
    {label: t`7 am`, value: 7},
    {label: t`8 am`, value: 8},
    {label: t`9 am`, value: 9},
    {label: t`10 am`, value: 10},
    {label: t`11 am`, value: 11},
    {label: t`12 pm`, value: 12},

    {label: t`1 pm`, value: 13},
    {label: t`2 pm`, value: 14},
    {label: t`3 pm`, value: 15},
    {label: t`4 pm`, value: 16},
    {label: t`5 pm`, value: 17},
    {label: t`6 pm`, value: 18},
    {label: t`7 pm`, value: 19},
    {label: t`8 pm`, value: 20},
    {label: t`9 pm`, value: 21},
    {label: t`10 pm`, value: 22},
    {label: t`11 pm`, value: 23},
    {label: t`12 am (Day End)`, value: 24},
];

export const CalendarConfigButton: React.FunctionComponent = React.memo(observer(() => {
    const config = CalendarConfigStore.selectedModel;
    // eslint-disable-next-line react-hooks/rules-of-hooks
    const [open, , setClosed, toggleOpen] = useFlag(false);

    return <>
        <IconButton onClick={toggleOpen}>
            <Settings/>
        </IconButton>
        <Dialog fullWidth maxWidth={"md"} open={open} onClose={setClosed}>
            <DialogTitle>
                <Trans>Shift Calendar Settings</Trans>
            </DialogTitle>
            <DialogContent>
                {config ?
                    <ModelForm model={config} afterSubmit={setClosed}
                               suppressWrapper suppressImportExport suppressMakeCopy suppressRedirect>
                        <ModelSelect name={'start'} options={timeOptions}/>
                        <ModelSelect name={'end'} options={timeOptions.map(o => {
                            return {
                                ...o,
                                isDisabled: o.value <= config.viewModel.start
                            }
                        })}/>
                        <div>
                            <ModelCheckbox name={'weekend'}/>
                        </div>
                    </ModelForm>
                    : null}
            </DialogContent>
        </Dialog>
    </>
}));