import * as React from "react";
import {ButtonField, Conditional, HintButton, IfFalse, IfTrue} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {Grid, Typography,} from "@material-ui/core";
import {t, Trans} from "@lingui/macro";
import {FileUpload} from "../generic/FileUpload";
import {makeStyles} from "@material-ui/core/styles";
import {grey, red} from "@material-ui/core/colors";
import {SystemSettingModel} from "../../stores/SystemSettingStore";
import classNames from "classnames";


const useStyles = makeStyles(() => ({
    imagePreview: {
        display: 'inline-block',
        border: 'solid 1px',
        borderColor: grey[200]
    },
    noLogoWrapper: {
        padding: '5px',
        minHeight: '100px',
        minWidth: '100px',
    },
    delete: {
        backgroundColor: red[500]
    }
}));

export type CustomerLogoSettingsSectionProps = {
    model: SystemSettingModel;
};

export const CustomerLogoSettingsSection: React.FunctionComponent<CustomerLogoSettingsSectionProps> = observer(({model}) => {
    const classes = useStyles();

    const handleSelectImage = React.useCallback((e: any) => {
        if (e.target.files.length > 0) {
            model.viewModel.file = e.target.files[0];
        }
    }, [model]);

    const handleDeleteLogo = React.useCallback(() => {
        // Already uploaded logo
        if (model.viewModel.has_customer_logo) {
            model.viewModel.clear_logo = true;
            model.viewModel.has_customer_logo = false;
        }
        // New logo
        if (model.viewModel.file) {
            model.viewModel.file = undefined;
        }
    }, [model]);

    const noLogoLoaded = !(model.viewModel.file || model.viewModel.has_customer_logo);

    const logoSrc = React.useCallback(() => {
        // Prefer freshly uploaded file over existing logo
        if (model.viewModel.file) {
            return URL.createObjectURL(model.viewModel.file);
        }
        return '/api/system_settings/customer_logo';
    }, [model.viewModel])

    return (
        <React.Fragment>
            <Grid container alignItems={'center'}>
                <Typography variant={"h5"}><Trans>Customer Logo</Trans></Typography>
                <HintButton title={t`Customer Logo`}
                            text={t`This logo will be used throughout the application such as in the reports and the dashboards header.`}/>
            </Grid>
            <FileUpload onChange={handleSelectImage} fileName={'fileName'}/>
            <Conditional condition={noLogoLoaded}>
                <IfFalse>
                    <ButtonField size={'small'} text={t`Remove Logo`} className={classes.delete}
                                 onClick={handleDeleteLogo}/>
                </IfFalse>
            </Conditional>
            <div>
                <div>
                    <Conditional condition={noLogoLoaded}>
                        <IfTrue>
                            <div className={classNames(classes.noLogoWrapper, classes.imagePreview)}>
                                <Trans>No Logo Uploaded</Trans>
                            </div>
                        </IfTrue>
                        <IfFalse>
                            <img className={classes.imagePreview} src={logoSrc()} alt={'logo'}/>
                        </IfFalse>
                    </Conditional>
                </div>
            </div>
        </React.Fragment>
    )
})