import * as React from 'react';
import {observer} from "mobx-react-lite";
import {ButtonField, PaddedPaper} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {UserModel} from "../../stores/UserStore";
import {VpnKey} from "@material-ui/icons";
import {Popover, Typography} from "@material-ui/core";

export const PasswordRecoveryEmailButton: React.FunctionComponent<{ user: UserModel }> = observer(({user}) => {
    const disabled = !user.email;
    const [anchor, setAnchor] = React.useState(null);
    const [pending, setPending] = React.useState(false);
    const open = !!anchor;
    const sendClick = React.useCallback(e => {
        setPending(true);
        const target = e.currentTarget;
        user.sendPasswordResetLink().then(() => {
            setPending(false);
            setAnchor(target);
        });
    }, [setAnchor, setPending, user]);
    const closePopup = React.useCallback(() => {
        setAnchor(null);
    }, [setAnchor]);
    return <React.Fragment>
        <ButtonField text={t`Issue Password Recovery Email`}
                     startIcon={<VpnKey/>}
                     onClick={sendClick}
                     loading={pending}
                     tooltip={disabled ? t`You must save the user with a valid email before you can use this button` : t`Send the user an email to reset their password`}
                     disabled={disabled}/>
        <Popover anchorEl={anchor} open={open}
                 onClose={closePopup}
                 anchorOrigin={{
                     vertical: 'bottom',
                     horizontal: 'center',
                 }}
                 transformOrigin={{
                     vertical: 'top',
                     horizontal: 'center',
                 }}
        >
            <PaddedPaper>
                <Typography
                    variant={'caption'}>{t`Email has been queued for sending.  Delivery may take a few moments.`}</Typography>
            </PaddedPaper>
        </Popover>
    </React.Fragment>
});