import {AppSwitcherMenu, dataStorePermission, RouteDefinition} from "@rx-suite/ui";
import {RolesBreadModel} from './pages/roles/RolesBreadModel';
import {UsersBreadModel} from "./pages/users/UsersBreadModel";
import {Apps, DateRange, Email, Event, EventNote, People, Person, Settings, VpnKey} from '@material-ui/icons';
import {RxModuleComponentStore} from './stores/RxModuleComponentStore';
import {UserStore} from './stores/UserStore';
import {RoleStore} from './stores/RoleStore';
import {EmailStore} from "./stores/EmailStore";
import {EmailsBreadModel} from "./pages/emails/EmailsBreadModel";
import Profile from "./pages/Profile";
import {PasswordResetForm} from "./pages/password_reset/PasswordResetForm";
import {t} from "@lingui/macro";
import {AppsPage} from "./pages/apps/AppsPage";
import {AppInstallPage} from "./pages/apps/AppInstallPage";
import {LicenceForm} from "./pages/licence/LicenceForm";
import {ShiftStore} from "./stores/ShiftStore";
import {Shifts} from "./pages/shifts/Shifts";
import {ShiftsCalendar} from "./components/shifts/ShiftsCalendar";
import {SystemSettingForm} from "./pages/system_settings/SystemSettingForm";
import {SystemSettingStore} from "./stores/SystemSettingStore";

export const routes: RouteDefinition[] = [
    {
        label: '',
        to: "/",
        exact: true,
        Component: AppSwitcherMenu
    },
    {
        label: t`Apps`,
        to: "/apps",
        exact: false,
        permission: dataStorePermission(RxModuleComponentStore),
        help: t`An App is an Rx-Suite Module or an Rx-Suite compatible module.  Apps on this list can see and communicate with each other.`,
        Component: AppsPage,
        Icon: Apps
    },
    {
        to: "/install",
        help: t`The selected app will be installed on the same server as Hub`,
        exact: false,
        Component: AppInstallPage
    },
    {
        label: t`Users`,
        to: "/users",
        help: t`Manage people who are allowed to interact with Rx-Suite`,
        exact: false,
        permission: dataStorePermission(UserStore),
        Component: UsersBreadModel,
        Icon: Person
    },
    {
        to: "/password_reset/:user/:token",
        exact: false,
        Component: PasswordResetForm,
    },
    {
        label: t`Roles`,
        to: "/roles",
        help: t`A Role is a set of allowed actions that member Users can take`,
        exact: false,
        permission: dataStorePermission(RoleStore),
        Component: RolesBreadModel,
        Icon: People
    },
    {
        label: t`Shifts`,
        to: "",
        exact: false,
        permission: dataStorePermission(ShiftStore),
        Icon: DateRange,
        children: [
            {
                to: "/shifts",
                label: t`Manage Shifts`,
                help: t`A Shift is a recurring schedule`,
                exact: false,
                Component: Shifts,
                Icon: EventNote
            },
            {
                to: "/calendar",
                label: t`Calendar`,
                exact: false,
                Component: ShiftsCalendar,
                Icon: Event
            }
        ]
    },
    {
        label: t`Emails`,
        to: "/emails",
        help: t`Setup Email credentials that Apps will use when sending messages`,
        exact: false,
        permission: dataStorePermission(EmailStore),
        Component: EmailsBreadModel,
        Icon: Email
    },
    {
        label: t`System Settings`,
        to: "/system_settings",
        help: t`Settings that will apply to every module`,
        exact: false,
        Component: SystemSettingForm,
        permission: dataStorePermission(SystemSettingStore),
        Icon: Settings
    },
    {
        label: t`My Profile`,
        to: "/profile",
        help: t`Manage information associated with your user account.`,
        exact: true,
        Component: Profile,
    },
    {
        label: t`Licence`,
        to: "/licence",
        help: t`View and managed the licenced components of the software`,
        exact: true,
        Component: LicenceForm,
        permission: {
            target: 'licence_info',
            action: ['read', 'update']
        },
        Icon: VpnKey
    }
];
