import {Transport} from "@rx-suite/data";
import {UserModel} from "../stores/UserStore";

export class UsersTransport extends Transport<UserModel> {
    constructor() {
        super('/api/users', 'user');
    }

    async resetPassword(id: string, token: string, password: string, passwordConfirmation: string) {
        const resp = await this.fetch(`/${id}/password`, {
            method: "POST",
            body: JSON.stringify({
                token: token,
                password: password,
                passwordConfirmation: passwordConfirmation,
            }),
            headers: {
                "Content-Type": "application/json"
            }
        });
        return this.parseJson(resp);
    }

    async sendPasswordResetLink(id: string) {
        const resp = await this.fetch(`/${id}/send_password`, {
            method: "POST",
            body: JSON.stringify({}),
            headers: {
                "Content-Type": "application/json"
            }
        });
        return this.parseJson(resp);
    }

    async getPasswordResetLink(id: string) {
        const resp = await this.fetch(`/${id}/get_password_link`, {
            method: "POST",
            body: JSON.stringify({}),
            headers: {
                "Content-Type": "application/json"
            }
        });
        return this.parseJson(resp);
    }
}